=====================
CiscoIosInterfaceLine
=====================
.. _cisco-ios-interface-line:


..  autoclass:: ccutils.ccparser.CiscoIosInterfaceLine
    :members:
    :undoc-members:
    :show-inheritance:
